@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2012-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -31,13 +31,13 @@ struct tagStruct {
     QString name;
     QColor color;
 };
-Q_DECLARE_TYPEINFO(tagStruct, Q_MOVABLE_TYPE);
+Q_DECLARE_TYPEINFO(tagStruct, Q_RELOCATABLE_TYPE);
 
 namespace ImportWizardUtil
 {
 enum ResourceType { Imap, Pop3, Ldap };
 
 LIBIMPORTWIZARD_EXPORT void mergeLdap(const ldapStruct &ldap);
-LIBIMPORTWIZARD_EXPORT void addAkonadiTag(const QVector<tagStruct> &tagList);
+LIBIMPORTWIZARD_EXPORT void addAkonadiTag(const QList<tagStruct> &tagList);
 void storePassword(const QString &name, ImportWizardUtil::ResourceType type, const QString &password);
 }
