@@ -19,7 +19,7 @@ void EvolutionAddressBook::exportEvolutionAddressBook()
 {
     KMessageBox::information(mAbstractDisplayInfo->parentWidget(),
                              i18n("Evolution address book will be exported as vCard. Import vCard in KAddressBook."),
-                             i18n("Export Evolution Address Book"));
+                             i18nc("@title:window", "Export Evolution Address Book"));
 
     const QString directory =
         QFileDialog::getExistingDirectory(mAbstractDisplayInfo->parentWidget(), i18n("Select the directory where vCards will be stored."));
@@ -87,3 +87,5 @@ void EvolutionAddressBook::exportEvolutionAddressBook()
         }
     }
 }
+
+#include "moc_evolutionaddressbook.cpp"
